{% extends "admin/kmuhelper/base_site.html" %}

{% load static kmuhelper_tags %}

{% block title %}KMUHelper{% endblock %}

{% block branding %}
    <h1 id="site-name"><a target="_top" href="{% url 'kmuhelper:home' %}">KMUHelper</a></h1>
{% endblock %}

{% block breadcrumbs %}{% endblock %}

{% block extrastyle %}
    {{ block.super }}
    <link rel="stylesheet" href="{% static 'admin/kmuhelper/css/pagechooser.css' %}">
    {% include "admin/kmuhelper/_includes/fontawesome.html" %}
{% endblock %}

{% block content %}
    <h1>Willkommen im KMUHelper!</h1>

    {% kmuhelper_pagechooser grid %}
{% endblock %}
