{% extends "admin/index.html" %}
{% load static kmuhelper_tags %}

{% block extrastyle %}
    {{ block.super }}
    <link rel="stylesheet" href="{% static "admin/kmuhelper/css/index-kmuhelper.css" %}">
    {% include "admin/kmuhelper/_includes/fontawesome.html" %}
{% endblock %}

{% block content %}

    {% if not app_label %}
        {% if perms.kmuhelper %}
            {% kmuhelper_open_kmuhelper_button %}
        {% endif %}
    {% endif %}

    {{ block.super }}
{% endblock %}