{% if show %}
    <div style="margin-bottom: 32px;">
        <a href="{{ home_url }}" id="kmuhelperbutton">
            <i class="fa-solid fa-box-open"></i>
            <h2>KMUHelper öffnen</h2>
        </a>
    </div>
{% endif %}
